@@ -1,4 +1,5 @@
 from . import DATA_DIR
+import sys
 import glob
 from .background_systems import BackgroundSystemModel
 from .export import ExportInventory
@@ -686,7 +687,7 @@ class InventoryCalculation:
             response = xr.DataArray(
                 B,
                 coords=[
-                    [2020, 2030, 2040, 2050],
+                    [2005, 2010, 2020, 2030, 2040, 2050],
                     self.get_dict_impact_categories()["recipe"]["midpoint"],
                     list(self.inputs.keys()),
                 ],
@@ -965,7 +966,7 @@ class InventoryCalculation:
             ],
             -self.number_of_cars :,
         ] = (
-            (array[self.array_inputs["lightweighting"], :])
+            (array[self.array_inputs["lightweighting"], :] * array[self.array_inputs["glider base mass"], :])
             / array[self.array_inputs["lifetime kilometers"], :]
             * -1
         )
@@ -1284,8 +1285,9 @@ class InventoryCalculation:
 
         losses_to_low = float(self.bs.losses[battery_origin]["LV"])
         mix_battery_manufacturing = (
-            self.bs.electricity_mix.sel(country=battery_origin, value=0)
-            .interp(year=self.scope["year"])
+            self.bs.electricity_mix.sel(country=battery_origin,
+            variable=["Hydro","Nuclear","Gas","Solar","Wind","Biomass","Coal","Oil","Geothermal","Waste"])
+            .interp(year=self.scope["year"], kwargs={"fill_value": "extrapolate"})
             .values
         )
 
@@ -1581,18 +1583,6 @@ class InventoryCalculation:
             * -1
         ).T
 
-        if not any(
-            True for x in ["BEV", "PHEV-p", "PHEV-d"] if x in self.scope["powertrain"]
-        ):
-            self.background_configuration["custom electricity mix"] = [
-                self.bs.electricity_mix.sel(
-                    country=self.background_configuration["country"], value=0
-                )
-                .interp(year=y)
-                .values
-                for y in self.scope["year"]
-            ]
-
         country = self.background_configuration["country"]
         try:
             losses_to_low = float(self.bs.losses[country]["LV"])
@@ -1600,9 +1590,7 @@ class InventoryCalculation:
             # If losses for the country are not found, assume 15%
             losses_to_low = 1.15
 
-        if "custom electricity mix" in self.background_configuration or not any(
-            True for x in ["BEV", "PHEV-p", "PHEV-d"] if x in self.scope["powertrain"]
-        ):
+        if "custom electricity mix" in self.background_configuration:
             # If a special electricity mix is specified, we use it
             mix = self.background_configuration["custom electricity mix"]
             print("The electricity mix is provided by the user.", end="\n \t * ")
@@ -1628,16 +1616,18 @@ class InventoryCalculation:
             ]
 
             mix = [
-                self.bs.electricity_mix.sel(country=country, value=0)
-                .interp(year=np.arange(y, y + use_year[self.scope["year"].index(y)]))
-                .mean(axis=0)
-                .values
+                self.bs.electricity_mix.sel(country=country,
+                variable=["Hydro","Nuclear","Gas","Solar","Wind","Biomass","Coal","Oil","Geothermal","Waste"])
+                .interp(year=np.arange(y, y + use_year[self.scope["year"].index(y)]), kwargs={"fill_value": "extrapolate"}).mean(axis=0).values
+                if y + use_year[self.scope["year"].index(y)] <= 2050 else self.bs.electricity_mix.sel(country=country,
+                variable=["Hydro","Nuclear","Gas","Solar","Wind","Biomass","Coal","Oil","Geothermal","Waste"]).interp(year=np.arange(y, 2051), kwargs={"fill_value": "extrapolate"}).mean(axis=0).values
                 for y in self.scope["year"]
             ]
 
         for y in self.scope["year"]:
             sum_renew = (
                 mix[self.scope["year"].index(y)][0]
+                + mix[self.scope["year"].index(y)][3]
                 + mix[self.scope["year"].index(y)][4]
                 + mix[self.scope["year"].index(y)][5]
                 + mix[self.scope["year"].index(y)][8]
@@ -1834,13 +1824,13 @@ class InventoryCalculation:
                         print(
                             "The values for hydrogen shares do not match the number of years."
                         )
-                        exit(1)
+                        sys.exit(1)
             try:
                 type_primary_fcev
             except NameError:
-                type_primary_fcev = 'hydrogen - smr'
-                type_secondary_fcev = 'hydrogen - electrolysis'
-                share_secondary_fcev = np.linspace(0,0.5, len(self.scope["year"]))
+                type_primary_fcev = 'electrolysis'
+                type_secondary_fcev = 'smr'
+                share_secondary_fcev = np.linspace(0,0, len(self.scope["year"]))
                 share_primary_fcev =  1 - share_secondary_fcev
 
             print("{} is completed by {}.".format(type_primary_fcev, type_secondary_fcev), end="\n \t * ")
@@ -1859,18 +1849,25 @@ class InventoryCalculation:
                 )
 
             dict_h_map = {
-                "hydrogen - electrolysis": (
+                "electrolysis": (
                     "Hydrogen, gaseous, 700 bar, from electrolysis, at H2 fuelling station",
                     "RER",
                     "kilogram",
                     "Hydrogen, gaseous, 700 bar, from electrolysis, at H2 fuelling station",
                 ),
-                "hydrogen - smr": (
+                "smr": (
                     "Hydrogen, gaseous, 700 bar, from SMR NG w/o CCS, at H2 fuelling station",
                     "RER",
                     "kilogram",
                     "Hydrogen, gaseous, 700 bar, from SMR NG w/o CCS, at H2 fuelling station",
                 )
+                ,
+                "smr with CCS": (
+                    "Hydrogen, gaseous, 700 bar, from SMR NG w CCS, at H2 fuelling station",
+                    "RER",
+                    "kilogram",
+                    "Hydrogen, gaseous, 700 bar, from SMR NG w CCS, at H2 fuelling station",
+                )
             }
 
             # Primary fuel share
@@ -1910,9 +1907,9 @@ class InventoryCalculation:
                 ).T
 
                 # If hydrolysis is chosen, adjust the electricity mix
-                if type_primary_fcev == "hydrogen - electrolysis":
+                if type_primary_fcev == "electrolysis":
                         share = share_primary_fcev
-                elif type_secondary_fcev == "hydrogen - electrolysis":
+                elif type_secondary_fcev == "electrolysis":
                     share = share_secondary_fcev
                 else:
                     share = np.zeros_like(self.scope['year'])
@@ -1973,7 +1970,7 @@ class InventoryCalculation:
                             fuel_type='Biomass fuel',
                             scenario=scenario,
                         )
-                        .interp(year=self.scope["year"])
+                        .interp(year=self.scope["year"], kwargs={"fill_value": "extrapolate"})
                         .values
                     )
                 share_primary_icevg = 1 - share_secondary_icevg
@@ -2075,6 +2072,32 @@ class InventoryCalculation:
                     * -1
                 ).T
 
+                # If syngas is chosen, adjust the electricity mix needed to produce the hydrogen
+                if type_primary_icevg == "syngas":
+                    share = share_primary_icevg
+                elif type_secondary_icevg == "syngas":
+                    share = share_secondary_icevg
+                else:
+                    share = np.zeros_like(self.scope['year'])
+
+                if share.sum() > 0:
+                    self.A[
+                        :,
+                        [
+                            self.inputs[i]
+                            for i in self.inputs
+                            if str(y) in i[0]
+                            and "electricity market for fuel preparation" in i[0]
+                        ],
+                        ind_A,
+                    ] = (
+                        (
+                                (array[self.array_inputs["fuel mass"], :, ind_array] * share[self.scope["year"].index(y)])
+                            / array[self.array_inputs["range"], :, ind_array]
+                        )
+                        * -58 * 0.50779661 # kWh/kg hydrogen, times amount of hydrogen per kg of syngas
+                    ).T
+
         if [i for i in self.scope["powertrain"] if i in ["ICEV-d", "PHEV-d", "HEV-d"]]:
             index = self.get_index_from_array(["ICEV-d", "PHEV-d", "HEV-d"])
 
@@ -2113,7 +2136,7 @@ class InventoryCalculation:
                             fuel_type='Biomass fuel',
                             scenario=scenario,
                         )
-                        .interp(year=self.scope["year"])
+                        .interp(year=self.scope["year"], kwargs={"fill_value": "extrapolate"})
                         .values
                     )
                 share_primary_icevd = 1 - share_secondary_icevd
@@ -2161,7 +2184,6 @@ class InventoryCalculation:
                     end=end_str,
                 )
 
-
             for y in self.scope["year"]:
                 ind_A = [
                     self.inputs[i]
@@ -2227,6 +2249,32 @@ class InventoryCalculation:
                     * -1
                 ).T
 
+                # If synthetic diesel is chosen, adjust the electricity mix needed to produce the hydrogen
+                if type_primary_icevd == "synthetic diesel":
+                    share = share_primary_icevd
+                elif type_secondary_icevd == "synthetic diesel":
+                    share = share_secondary_icevd
+                else:
+                    share = np.zeros_like(self.scope['year'])
+
+                if share.sum() > 0:
+                    self.A[
+                        :,
+                        [
+                            self.inputs[i]
+                            for i in self.inputs
+                            if str(y) in i[0]
+                            and "electricity market for fuel preparation" in i[0]
+                        ],
+                        ind_A,
+                    ] = (
+                        (
+                                (array[self.array_inputs["fuel mass"], :, ind_array] * share[self.scope["year"].index(y)])
+                            / array[self.array_inputs["range"], :, ind_array]
+                        )
+                        * -58 * 0.103 # kWh/kg hydrogen, times amount of hydrogen per kg of syngas (RWGS)
+                    ).T
+
         if [i for i in self.scope["powertrain"] if i in ["ICEV-p", "HEV-p", "PHEV-p"]]:
             index = self.get_index_from_array(["ICEV-p", "HEV-p", "PHEV-p"])
 
@@ -2265,7 +2313,7 @@ class InventoryCalculation:
                             fuel_type='Biomass fuel',
                             scenario=scenario,
                         )
-                        .interp(year=self.scope["year"])
+                        .interp(year=self.scope["year"], kwargs={"fill_value": "extrapolate"})
                         .values
                     )
                 share_primary_icevp = 1 - share_secondary_icevp
@@ -2389,6 +2437,32 @@ class InventoryCalculation:
                     * -1
                 ).T
 
+                # If synthetic gasoline is chosen, adjust the electricity mix needed to produce the hydrogen
+                if type_primary_icevp == "synthetic gasoline":
+                    share = share_primary_icevp
+                elif type_secondary_icevp == "synthetic gasoline":
+                    share = share_secondary_icevp
+                else:
+                    share = np.zeros_like(self.scope['year'])
+
+                if share.sum() > 0:
+                    self.A[
+                        :,
+                        [
+                            self.inputs[i]
+                            for i in self.inputs
+                            if str(y) in i[0]
+                            and "electricity market for fuel preparation" in i[0]
+                        ],
+                        ind_A,
+                    ] = (
+                        (
+                                (array[self.array_inputs["fuel mass"], :, ind_array] * share[self.scope["year"].index(y)])
+                            / array[self.array_inputs["range"], :, ind_array]
+                        )
+                        * -58 * 3.24e-04 # kWh/kg hydrogen, times amount of hydrogen per kg of syngas (RWGS)
+                    ).T
+
         # Non-exhaust emissions
         self.A[
             :,
@@ -2435,7 +2509,6 @@ class InventoryCalculation:
         ] = (5.37e-7 * array[self.array_inputs["driving mass"], :] * -1)
 
         # Exhaust emissions
-
         # Non-fuel based emissions
         self.A[:, self.index_emissions, -self.number_of_cars :] = (
             array[
